/* $Workfile: OtxDspD.h $   $Revision: 48 $    $Modtime: 8/23/02 12:51p $  */
#ifndef OTX_DSP_DEF_H
#define OTX_DSP_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxDspD

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxDspD | Constants, Macros, and Types for the DSP Device Management Functions

  @contents2
  OtxDspD.h |

  @index enum struct type | OtxDspD

  @contents2
  OTX DSP Device Management Macros, Constants, and Types |

  @head3 OtxDspXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxDspD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************
  @enum Standard Program Modules (SPM)

  @comm These DSP program modules can be loaded in the DSPs by 
  calling <f OtxDspRunSpm>.

  @comm OtxSpm1 supports the following logical devices:
   8 OTX_LDEVICE_HDLC_RECEIVER  (all 8 can not be enabled at one time)
   8 OTX_LDEVICE_HDLC_SENDER    (all 8 can not be enabled at one time)
   8 OTX_LDEVICE_DATA_RAW_RECEIVER  (all 8 can not be enabled at one time)
   8 OTX_LDEVICE_DATA_RAW_SENDER    (all 8 can not be enabled at one time)
   16 OTX_LDEVICE_TONE_DTMF_DETECTOR
   16 OTX_LDEVICE_TONE_DTMF_DIALER
   16 OTX_LDEVICE_TONE_EFFECTS_GENERATOR
   16 OTX_LDEVICE_DATA_CONVERTER
   16 OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
   16 OTX_LDEVICE_TONE_VAL_SAMPLER
   16 OTX_LDEVICE_TONE_SINEWAVE_GENERATOR
   16 OTX_LDEVICE_TONE_SILENCE_DETECTOR
   16 OTX_LDEVICE_TONE_FSK_DETECTOR

  @comm OtxOTX supports pipes of capacity 64kbps and 128kbps.

  @comm OtxSpm2 supports the following logical devices:
   8 OTX_LDEVICE_HDLC_SENDER
   8 OTX_LDEVICE_HDLC_RECEIVER
   8 OTX_LDEVICE_DATA_RAW_SENDER
   8 OTX_LDEVICE_DATA_RAW_RECEIVER
   8 OTX_LDEVICE_TONE_FSK_DETECTOR
   8 OTX_LDEVICE_TONE_DTMF_DETECTOR
   8 OTX_LDEVICE_TONE_MF_DETECTOR
   8 OTX_LDEVICE_TONE_DUAL_DETECTOR
   8 OTX_LDEVICE_TONE_SINGLE_DETECTOR
   8 OTX_LDEVICE_TONE_DTMF_GENERATOR
   8 OTX_LDEVICE_TONE_DTMF_DIALER
   8 OTX_LDEVICE_TONE_MF_DIALER
   8 OTX_LDEVICE_TONE_EFFECTS_GENERATOR
   8 OTX_LDEVICE_DATA_CONVERTER
   8 OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
   8 OTX_LDEVICE_TONE_VAL_SAMPLER
   8 OTX_LDEVICE_TONE_SINEWAVE_GENERATOR
   8 OTX_LDEVICE_TONE_SILENCE_DETECTOR

  @comm OtxSpm2 supports pipes of capacity 64kbps and 128kbps.

  @comm OtxHdlc supports the following logical devices:
   32 OTX_LDEVICE_HDLC_RECEIVER  (all 32 can not be enabled at one time)
   32 OTX_LDEVICE_HDLC_SENDER    (all 32 can not be enabled at one time)
   32 OTX_LDEVICE_DATA_RAW_SENDER
   32 OTX_LDEVICE_DATA_RAW_RECEIVER
   32 OTX_LDEVICE_DATA_CONVERTER

  @comm OtxHdlc supports pipes of capacity 8kbps, 16kbps, 32kbps and n*64kbps.

  @comm OtxDtTx supports the following logical devices:
   32 OTX_LDEVICE_TONE_DTMF_DIALER  
   32 OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
   32 OTX_LDEVICE_TONE_VAL_SAMPLER

  @comm OtxDtTx supports pipes of capacity 64kbps.

  @comm OtxSpm3 supports the following logical devices:
   2 OTX_LDEVICE_HDLC_RECEIVER  (all 8 can not be enabled at one time)
   2 OTX_LDEVICE_HDLC_SENDER    (all 8 can not be enabled at one time)
   2 OTX_LDEVICE_DATA_RAW_RECEIVER  (all 8 can not be enabled at one time)
   2 OTX_LDEVICE_DATA_RAW_SENDER    (all 8 can not be enabled at one time)
   30 OTX_LDEVICE_TONE_DTMF_DETECTOR
   30 OTX_LDEVICE_TONE_DTMF_DIALER
   30 OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
   30 OTX_LDEVICE_TONE_VAL_SAMPLER
   

  @comm OtxCas is not implemented yet.


*******************************************************************************/
enum OtxDspSpmE {
  OTX_DSP_SPM_OTXSPM1    ,   // @emem DSP Program OtxSpm1.out
  OTX_DSP_SPM_OTXSPM2    ,   // @emem DSP Program OtxSpm2.out
  OTX_DSP_SPM_OTXSPM3    ,   // @emem DSP Program OtxSpm3.out
  OTX_DSP_SPM_OTXHDLC    ,   // @emem DSP Program OtxHdlc.out
  OTX_DSP_SPM_OTXDTTX    ,   // @emem DSP Program OtxDtTx.out
  OTX_DSP_SPM_CAS        ,   // @emem DSP Program OtxSpmCas.out
  OTX_DSP_BERT			 ,	 // @emem DSP bert program bert.out
  OTX_DSP_DIAG			 ,	 // @emem DSP Diagnostics program
  OTX_DSP_DS0			 ,	 // @emem DSP DS0 Visual program
};

typedef enum OtxDspSpmE OtxDspSpmE;


/*---------------------------------------------------------------------------*\
  @enum 
    DSP Device Attributes
\*---------------------------------------------------------------------------*/
enum OtxDspDeviceAttributesE {
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_CURRENT_USAGE            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of words in use of the 
                                                                                    // HPI Notification Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_MAX_USAGE                = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read-only. Maximum number of words in use of the 
                                                                                    // HPI Notification Event Buffer (since the application started)
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_LOST_EVENTS              = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read-only. Number of the lost events (due to a 
                                                                                    // full HPI Notification Event Buffer)
  OTX_ATTR_DSP_NOTIFICATION_EVENT_EXT_QUEUE_CURRENT_USAGE      = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  
  OTX_ATTR_DSP_NOTIFICATION_EVENT_EXT_QUEUE_PEAK_USAGE         = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  

  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_ADDR                     = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the HPI Notification 
                                                                                    // Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_SIZE                     = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Size (in words) of the HPI Notification Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_PROCESSING_ADDR          = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Address of where the host driver will 
                                                                                    // write the address of its Notification Event Buffer Read Pointer (i.e. the 
                                                                                    // address of where it will read the next Notification Event from)
  OTX_ATTR_DSP_IOCTL_CODE_ADDR                                 = OTX_ATTR_END + 8,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the DSP IO Control packet.
  OTX_ATTR_DSP_IOCTL_DATA_MAX_SIZE                             = OTX_ATTR_END + 9,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Maximum data length of the DSP IO Control 
                                                                                    // packet.
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_HANDLE           = OTX_ATTR_END + 10,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // DSP Handle in the Notification Events
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_TASKREF          = OTX_ATTR_END + 11,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // TaskRef in the Notification Events
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_TIMESTAMP        = OTX_ATTR_END + 12, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // TimeStamp in the Notification Events
  OTX_ATTR_DSP_IOCTL_INCLUDE_HANDLE                            = OTX_ATTR_END + 13, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include the 
                                                                                    // DSP Handle in the DSP IO Control packet
  OTX_ATTR_DSP_IOCTL_INCLUDE_TASKREF                           = OTX_ATTR_END + 14, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include 
                                                                                    // the TaskRef in the DSP IO Control packet
  OTX_ATTR_DSP_AUTO_DISABLE                                    = OTX_ATTR_END + 15, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_TRUE. If OTX_TRUE the driver 
                                                                                    // will automatically disable the device if the Notification Event buffer encounters
                                                                                    // to many serious errors. A call to <f OtxDrvReset> will reset the error counter for
                                                                                    // serious errors.
                                                              
  OTX_ATTR_DSP_END                                             = OTX_ATTR_END + 16
};

typedef enum OtxDspDeviceAttributesE OtxDspDeviceAttributesE;

/*---------------------------------------------------------------------------*\
  @enum
    DSP Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDspResultCodesE {
  OTX_DSP_RES_DATA_TOO_LARGE               = OTX_RES_END +  0 ,  // @emem Data too large for the supplied buffer. Supply a larger buffer.
  OTX_DSP_RES_INVALID_CHANNEL              = OTX_RES_END +  1 ,  // @emem Invalid channel
  OTX_DSP_RES_COMM_FAILURE                 = OTX_RES_END +  2 ,  // @emem Communication failure with the DSP
  OTX_DSP_RES_NO_KERNEL_RESPONSE           = OTX_RES_END +  3 ,  // @emem No response from DSP Kernel
  OTX_DSP_RES_NO_FREE_LOGICAL_DEVICE       = OTX_RES_END +  4 ,  // @emem No free logical device

  OTX_DSP_RES_END                          = OTX_RES_END +  1
};

typedef enum OtxDspResultCodesE OtxDspResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DSP Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDspEventCodesE {
  // OtxSpm1 Specific Event Codes
  OTX_DSP_EC_RX_OVERFLOW                 = 0x00, // @emem OtxSpm1 Receive overflow
  OTX_DSP_EC_INTERNAL_ERROR              = 0x01, // @emem OtxSpm1 Undefined Internal error
  OTX_DSP_EC_UNKNOWN_NOTIFY_CODE         = 0x02, // @emem OtxSpm1 Error. Unknown notify code for System Notify Event Handle.

  // Generic DSP Module Event Codes
  OTX_DSP_EC_INVALID_NOTIFY_EVENT_HANDLE = 0x03, // @emem Invalid Notify Event Handle. Could not find a matching logical device for this handle.
  OTX_DSP_EC_NOTIFY_EVENT_OVERFLOW       = 0x04, // @emem Event frequency too high. Driver cannot handle all these events. 
  OTX_DSP_EC_AUTO_DISABLED               = 0x05, // @emem Fatal error has occurred. The device is automatically disabled.
  OTX_DSP_EC_NOTIFY_EVENT_FREQ_HIGH      = 0x06, // @emem Event frequency from the DSP is seriously high. Fatal errors are imminent.
//OTX_DSP_EC_DEBUG_INFO                  = 0x07, // @emem Internal use. For driver debugging.

//*****************************
#ifdef _TURNSTONE_
//*****************************
  OTX_DSP_EC_PATTERN_SYNC                = 0x06,
  OTX_DSP_EC_PATTERN_UNKNOWN             = 0x07,
  OTX_DSP_EC_RXBUFFER_OVERFLOW           = 0x08,
  OTX_DSP_EC_BITERROR_UPDATE             = 0x09,
  OTX_DSP_EC_TEST_PATTERN_FAILURE        = 0x0A,
  OTX_DSP_EC_TEST_PATTERN_SUCCESS        = 0x0B,
  OTX_DSP_EC_DS0VISUAL_UPDATE            = 0x0C,
//******************************
#endif   //_TURNSTONE_
//******************************

  OTX_DSP_END_OF_EVENT_CODES          
};
typedef enum OtxDspEventCodesE OtxDspEventCodesE;


/*---------------------------------------------------------------------------*\
  @enum
    User Application Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxUserApplicationResultCodesE {
  OTX_USER_APPLICATION_RES_DATA_TRUNCATED  = OTX_RES_END +  0 ,  // @emem DSP User application has transferred a data buffer that is too large. Data is truncated.        
  OTX_USER_APPLICATION_RES_END             = OTX_RES_END +  1
};

typedef enum OtxUserApplicationResultCodesE OtxUserApplicationResultCodesE;


/*---------------------------------------------------------------------------*\
  @enum
    DSP User Application Logical Device Event Codes
\*---------------------------------------------------------------------------*/
enum OtxUserApplicationEventCodesE {
  OTX_USER_APPLICATION_EC_READ_DATA                = 0x00, // @emem DSP User Application Notify Data is available
  OTX_USER_APPLICATION_EC_READ_DATA_OVERRUN        = 0x01, // @emem DSP User Application Notify Data Fifo Overrun. User application is too slow extracting data from the driver

  OTX_USER_APPLICATION_END_OF_EVENT_CODES          
};
typedef enum OtxUserApplicationEventCodesE OtxUserApplicationEventCodesE;


#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_DSP_DEF_H
